You are viewing a plain text version of this content. The canonical link for it is here.
Posted to scm@geronimo.apache.org by ga...@apache.org on 2013/03/19 15:42:15 UTC

svn commit: r1458320 - in /geronimo/specs/trunk: geronimo-jaxws_2.1.1_spec/src/main/java/javax/xml/ws/spi/ geronimo-jaxws_2.1_spec/src/main/java/javax/xml/ws/spi/ geronimo-jaxws_2.2_spec/src/main/java/javax/xml/ws/spi/

Author: gawor
Date: Tue Mar 19 14:42:15 2013
New Revision: 1458320

URL: http://svn.apache.org/r1458320
Log:
GERONIMO-6432: lookup the right properties file

Modified:
    geronimo/specs/trunk/geronimo-jaxws_2.1.1_spec/src/main/java/javax/xml/ws/spi/FactoryFinder.java
    geronimo/specs/trunk/geronimo-jaxws_2.1_spec/src/main/java/javax/xml/ws/spi/FactoryFinder.java
    geronimo/specs/trunk/geronimo-jaxws_2.2_spec/src/main/java/javax/xml/ws/spi/FactoryFinder.java

Modified: geronimo/specs/trunk/geronimo-jaxws_2.1.1_spec/src/main/java/javax/xml/ws/spi/FactoryFinder.java
URL: http://svn.apache.org/viewvc/geronimo/specs/trunk/geronimo-jaxws_2.1.1_spec/src/main/java/javax/xml/ws/spi/FactoryFinder.java?rev=1458320&r1=1458319&r2=1458320&view=diff
==============================================================================
--- geronimo/specs/trunk/geronimo-jaxws_2.2_spec/src/main/java/javax/xml/ws/spi/FactoryFinder.java (original)
+++ geronimo/specs/trunk/geronimo-jaxws_2.2_spec/src/main/java/javax/xml/ws/spi/FactoryFinder.java Tue Mar 19 14:42:15 2013
@@ -38,7 +38,7 @@ import org.apache.geronimo.osgi.locator.
  * when bundled as part of the JDK.
  * <p/>
  * This class is duplicated for each subpackage so keep it in sync.
- * It is package private and therefore is not exposed as part of the JAXRPC
+ * It is package private and therefore is not exposed as part of the JAXWS
  * API.
  */
 class FactoryFinder {
--- geronimo/specs/trunk/geronimo-jaxws_2.1.1_spec/src/main/java/javax/xml/ws/spi/FactoryFinder.java (original)
+++ geronimo/specs/trunk/geronimo-jaxws_2.1.1_spec/src/main/java/javax/xml/ws/spi/FactoryFinder.java Tue Mar 19 14:42:15 2013
@@ -38,7 +38,7 @@ import org.apache.geronimo.osgi.locator.
  * when bundled as part of the JDK.
  * <p/>
  * This class is duplicated for each subpackage so keep it in sync.
  * It is package private and therefore is not exposed as part of the JAXRPC
  * API.
  */
 class FactoryFinder {
@@ -175,11 +175,11 @@ class FactoryFinder {
                     } catch (SecurityException se) {
                     }
 
                     // try to read from $java.home/lib/xml.properties
                     try {
                         String javah = System.getProperty("java.home");
                         String configFile = javah + File.separator +
-                        "lib" + File.separator + "jaxrpc.properties";
+                        "lib" + File.separator + "jaxws.properties";
                         File f = new File(configFile);
                         if (f.exists()) {
                             Properties props = new Properties();
@@ -38,7 +38,7 @@ import org.apache.geronimo.osgi.locator.
  * <p/>
  * This class is duplicated for each subpackage so keep it in sync.
- * It is package private and therefore is not exposed as part of the JAXRPC
+ * It is package private and therefore is not exposed as part of the JAXWS
  * API.
  */
@@ -175,11 +175,11 @@ class FactoryFinder {
                     }
 
-                    // try to read from $java.home/lib/xml.properties
+                    // try to read from $java.home/lib/jaxws.properties
                     try {
                         String javah = System.getProperty("java.home");

Modified: geronimo/specs/trunk/geronimo-jaxws_2.1_spec/src/main/java/javax/xml/ws/spi/FactoryFinder.java
URL: http://svn.apache.org/viewvc/geronimo/specs/trunk/geronimo-jaxws_2.1_spec/src/main/java/javax/xml/ws/spi/FactoryFinder.java?rev=1458320&r1=1458319&r2=1458320&view=diff
==============================================================================
--- geronimo/specs/trunk/geronimo-jaxws_2.1_spec/src/main/java/javax/xml/ws/spi/FactoryFinder.java (original)
+++ geronimo/specs/trunk/geronimo-jaxws_2.1_spec/src/main/java/javax/xml/ws/spi/FactoryFinder.java Tue Mar 19 14:42:15 2013
@@ -36,7 +36,7 @@ import java.util.Properties;
  * when bundled as part of the JDK.
  * <p/>
  * This class is duplicated for each subpackage so keep it in sync.
  * It is package private and therefore is not exposed as part of the JAXRPC
  * API.
  */
 class FactoryFinder {
@@ -180,11 +180,11 @@ class FactoryFinder {
                     } catch (SecurityException se) {
                     }
                     
                     // try to read from $java.home/lib/xml.properties
                     try {
                         String javah = System.getProperty("java.home");
                         String configFile = javah + File.separator +
-                        "lib" + File.separator + "jaxrpc.properties";
+                        "lib" + File.separator + "jaxws.properties";
                         File f = new File(configFile);
                         if (f.exists()) {
                             Properties props = new Properties();
@@ -36,7 +36,7 @@ import java.util.Properties;
  * <p/>
  * This class is duplicated for each subpackage so keep it in sync.
- * It is package private and therefore is not exposed as part of the JAXRPC
+ * It is package private and therefore is not exposed as part of the JAXWS
  * API.
  */
@@ -180,11 +180,11 @@ class FactoryFinder {
                     }
                     
-                    // try to read from $java.home/lib/xml.properties
+                    // try to read from $java.home/lib/jaxws.properties
                     try {
                         String javah = System.getProperty("java.home");

Modified: geronimo/specs/trunk/geronimo-jaxws_2.2_spec/src/main/java/javax/xml/ws/spi/FactoryFinder.java
URL: http://svn.apache.org/viewvc/geronimo/specs/trunk/geronimo-jaxws_2.2_spec/src/main/java/javax/xml/ws/spi/FactoryFinder.java?rev=1458320&r1=1458319&r2=1458320&view=diff
==============================================================================